{% extends 'ehf_invoice/base.html' %}
{% load humanize %}

{% block content %}
    <h1>{{ supplier }}</h1>
    <h2>Fakturaer</h2>
    {% include 'ehf_invoice/invoices.html' with show_customer=True invoices=supplier.invoices.all %}
{% endblock %}